==> ktorrent_5.1.0.orig.tar.xz: ktorrent-5.1.0/plugins/infowidget/addtrackersdialog.h <==
/***************************************************************************
 *   Copyright (C) 2012 by                                                 *
 *   Joris Guisson <joris.guisson@gmail.com>                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KT_ADDTRACKERSDIALOG_H
#define KT_ADDTRACKERSDIALOG_H

#include <QDialog>

#include <KEditListWidget>


namespace kt
{

    /**
     * Dialog to add trackers
     */
    class AddTrackersDialog : public QDialog
    {
        Q_OBJECT
    public:
        AddTrackersDialog(QWidget* parent, const QStringList& tracker_hints);
        ~AddTrackersDialog();

        /// Get the tracker list
        QStringList trackerList() const;

    private:
        KEditListWidget* trackers;
    };

}

#endif // KT_ADDTRACKERSDIALOG_H

==> ktorrent-5.1.2.tar.xz: ktorrent-5.1.2/plugins/infowidget/addtrackersdialog.h <==
/***************************************************************************
 *   Copyright (C) 2012 by                                                 *
 *   Joris Guisson <joris.guisson@gmail.com>                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KT_ADDTRACKERSDIALOG_H
#define KT_ADDTRACKERSDIALOG_H

#include <QDialog>

#include <KEditListWidget>


namespace kt
{

    /**
     * Dialog to add trackers
     */
    class AddTrackersDialog : public QDialog
    {
        Q_OBJECT
    public:
        AddTrackersDialog(QWidget* parent, const QStringList& tracker_hints);
        ~AddTrackersDialog() override;

        /// Get the tracker list
        QStringList trackerList() const;

    private:
        KEditListWidget* trackers;
    };

}

#endif // KT_ADDTRACKERSDIALOG_H
